@@ -17,9 +17,6 @@ if not 'LOG_STREAMNAME' in os.environ:
 if not 'BASE_STREAM_NAME' in os.environ:    
     os.environ['BASE_STREAM_NAME'] = 'deepportfolio-real-time'    
 
-if not 'AWS_PROFILENAME' in os.environ:
-    os.environ['AWS_PROFILENAME'] = 'guest'
-
 os.environ['USER_COMPUTER'] = os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME']
 
 loaded=True
\ No newline at end of file
