@@ -11,8 +11,11 @@ import pytz
 
 from SharedData.Logger import Logger
 
+debug=False
+
 def S3SyncDownloadDataFrame(path,shm_name):
-    Logger.log.debug('AWS S3 Sync DataFrame %s...' % (shm_name))    
+    if debug:
+        Logger.log.debug('AWS S3 Sync DataFrame %s...' % (shm_name))    
 
     awsfolder = os.environ['S3_BUCKET']+'/'
     awsfolder = awsfolder+str(Path(shm_name).parents[0])
@@ -36,19 +39,21 @@ def S3SyncDownloadDataFrame(path,shm_name):
                 & (process.poll() is not None):
             break        
         if (output) and not (output.startswith('Completed')):
-            Logger.log.debug('AWSCLI:'+output.strip())  
+            if debug:
+                Logger.log.debug('AWSCLI:'+output.strip())  
 
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync DataFrame %s,%s DONE!' % (Logger.user,shm_name))
+        if debug:
+            Logger.log.debug('AWS S3 Sync DataFrame %s,%s DONE!' % (Logger.user,shm_name))
     else:
         Logger.log.error('AWS S3 Sync DataFrame %s,%s ERROR!' % (Logger.user,shm_name))
         Logger.log.error('AWS S3 Sync DataFrame \"%s\"' % (''.join(process.stderr.readlines())))
     return success
 
 def S3SyncDownloadTimeSeries(path,shm_name):    
-    Logger.log.debug('AWS S3 sync download timeseries %s...' % (shm_name))
+    #Logger.log.debug('AWS S3 sync download timeseries %s...' % (shm_name))
     awsfolder = os.environ['S3_BUCKET']+'/'+shm_name+'/' 
     env = os.environ.copy()
     env['PATH'] = sys.exec_prefix+r'\Scripts'
@@ -65,12 +70,15 @@ def S3SyncDownloadTimeSeries(path,shm_name):
                 & (process.poll() is not None):
             break    
         if (output) and not (output.startswith('Completed')):
-            Logger.log.debug('AWSCLI:'+output.strip())        
+            if debug:
+                Logger.log.debug('AWSCLI:'+output.strip())        
 
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync timeseries %s,%s DONE!' % (Logger.user,shm_name))
+        if debug:
+            Logger.log.debug('AWS S3 Sync timeseries %s,%s DONE!' % (Logger.user,shm_name))
+
     else:
         Logger.log.error('AWS S3 Sync timeseries %s,%s ERROR!' % (Logger.user,shm_name))
         Logger.log.error('AWS S3 Sync timeseries \"%s\"' % (''.join(process.stderr.readlines())))
@@ -78,7 +86,8 @@ def S3SyncDownloadTimeSeries(path,shm_name):
 
 def S3SyncDownloadMetadata(pathpkl,name):
     
-    Logger.log.debug('AWS S3 Sync download metadata %s...' % (name))
+    if debug:
+        Logger.log.debug('AWS S3 Sync download metadata %s...' % (name))
     folder=str(pathpkl.parents[0]).replace(\
         os.environ['DATABASE_FOLDER'],'')
     
@@ -106,12 +115,14 @@ def S3SyncDownloadMetadata(pathpkl,name):
                 & (process.poll() is not None):
             break        
         if (output) and not (output.startswith('Completed')):
-            Logger.log.debug('AWSCLI:'+output.strip())  
+            if debug:
+                Logger.log.debug('AWSCLI:'+output.strip())  
             
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync download metadata %s,%s DONE!' % (Logger.user,name))
+        if debug:
+            Logger.log.debug('AWS S3 Sync download metadata %s,%s DONE!' % (Logger.user,name))
     else:
         Logger.log.error('AWS S3 Sync download metadata %s,%s ERROR!' % (Logger.user,name))
         Logger.log.error('AWS S3 Sync download metadata \"%s\"' % (''.join(process.stderr.readlines())))
@@ -123,12 +134,14 @@ def S3Upload(localfilepath):
     remotefilepath = remotefilepath.replace('\\','/')        
     localfilepath = str(localfilepath).replace('\\','/')              
       
-    Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' ...')
+    if debug:
+        Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' ...')
     try:                
         session = boto3.Session()
         s3 = session.resource('s3')
         bucket = s3.Bucket(os.environ['S3_BUCKET'].replace('s3://',''))
         bucket.upload_file(localfilepath,remotefilepath.replace(os.environ['S3_BUCKET'],'')[1:])
-        Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' DONE!')
+        if debug:
+            Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' DONE!')
     except Exception as e:
         Logger.log.error(Logger.user+' Uploading to S3 '+localfilepath+' ERROR! %s' % str(e))
\ No newline at end of file
